/** @file
  Include file for Fdt HwInfoParser.

  Copyright (c) 2021, ARM Limited. All rights reserved.<BR>
  SPDX-License-Identifier: BSD-2-Clause-Patent
**/

#ifndef FDT_HW_INFO_PARSER_INCLUDE_H_
#define FDT_HW_INFO_PARSER_INCLUDE_H_

#include <Base.h>
#include <Library/DebugLib.h>
#include <Library/MemoryAllocationLib.h>

#endif // FDT_HW_INFO_PARSER_INCLUDE_H_
